﻿'taken from Infra app years ago

Imports System.Reflection
Imports System.Windows.Forms

Public Class FormsManager
    Private Sub New()
    End Sub

    '-----------------------------------------------------------------------------
    ' Loads a Form as an MDI Child. 
    ' Requires the Fully Qualified Form Name of the Form that we want to launch,
    ' Requires the Unique Form Key that will be assigned to the Form Tag, 
    ' Requires the actual MDI Parent Form that will contain this new one, 
    ' Requires the option to ensire Single Instance, otherwise we can get 
    ' multiple form instances loaded.
    ' default is single instance

    '-----------------------------------------------------------------------------
    Public Shared Function LoadMDIForm(ByVal FullyQualifiedFormName As String, _
                                ByVal UniqueFormKey As String, _
                                ByVal MDIparent As Form, _
                                ByVal EnsureSingleMDIChildInstance As Boolean) As Form

        Dim objForm As Form = GetMDIForm(FullyQualifiedFormName, UniqueFormKey, MDIparent, EnsureSingleMDIChildInstance)


        If (objForm Is Nothing) Then

        Else

            objForm.MdiParent = MDIparent


            If objForm.Visible = False Then
                objForm.Show()
            End If
        End If

        objForm.Activate()
        Return objForm
    End Function

    '-----------------------------------------------------------------------------
    ' Returns an actual Form that you can use as you wish. 
    ' Requires the Fully Qualified Form Name of the Form that we want to launch,
    ' Requires the Unique Form Key that will be assigned to the Form Tag, 
    ' Requires the actual MDI Parent Form that will contain this new one, 
    ' Requires the option to ensure Single Instance, otherwise we can get 
    ' multiple form instances loaded.
    '-----------------------------------------------------------------------------
    Public Shared Function GetMDIForm(ByVal FullyQualifiedFormName As String, _
                                    ByVal UniqueFormKey As String, _
                                    ByVal MDIparent As Form, _
                                    ByVal EnsureSingleMDIChildInstance As Boolean) As Form
        Dim objForm As Form = Nothing
        Dim blnIsFound As Boolean = False

        If EnsureSingleMDIChildInstance = True Then


            For Each objForm In MDIparent.MdiChildren
                If FullyQualifiedFormName = MDIparent.GetType.Namespace & "." & TypeName(objForm) AndAlso CType(objForm.Tag, String) = UniqueFormKey Then
                    blnIsFound = True
                    Exit For
                End If
            Next
        End If

        If blnIsFound = False Then
            objForm = GetFormFromAsm(FullyQualifiedFormName)
            If (Not objForm Is Nothing) Then
                objForm.Tag = UniqueFormKey
                objForm.Name = UniqueFormKey
            Else
                MessageBox.Show("Form Does Not Exist", "", MessageBoxButtons.OK, MessageBoxIcon.Information)
                'Exit Function
            End If

        End If

        Return objForm
    End Function

    '-----------------------------------------------------------------------------
    ' Returns a form that can be added to a Control Container
    '-----------------------------------------------------------------------------
    Public Shared Function GetFormForControlContainer(ByVal FullyQualifiedFormName As String, _
                                                      ByVal UniqueFormKey As String) As Form
        Dim objForm As Form = GetFormFromAsm(FullyQualifiedFormName)
        objForm.Tag = UniqueFormKey
        Return objForm
    End Function

    '-----------------------------------------------------------------------------
    ' Returns a form that is loaded from the executing Assembly using Reflection
    '-----------------------------------------------------------------------------
    Public Shared Function GetFormFromAsm(ByVal FullyQualifiedFormName As String) As Form
        Dim objAsm As [Assembly] = [Assembly].LoadFrom([Assembly].GetExecutingAssembly.CodeBase)
        Dim objFormType As Type = objAsm.GetType(FullyQualifiedFormName)

        If (Not objFormType Is Nothing) Then

            Dim objFormActivator As Object = Activator.CreateInstance(objFormType)
            If objFormActivator Is Nothing Then Throw New ApplicationException("Form: " + FullyQualifiedFormName + " could not be loaded. Please check the Namespace and Form Name and Try Again")
            Return DirectCast(objFormActivator, Form)
        Else


        End If


    End Function

End Class


